@@ -57,6 +57,7 @@ else:
     from aiohttp import ClientSession as Session  # type: ignore[no-redef]
     import asyncio
 
+
 GCE_METADATA_BASE = 'http://metadata.google.internal/computeMetadata/v1'
 GCE_METADATA_HEADERS = {'metadata-flavor': 'Google'}
 GCE_ENDPOINT_PROJECT = ('{}/project/project-id'.format((GCE_METADATA_BASE)))
@@ -218,7 +219,7 @@ class Token(object):
                                                  timeout=timeout)
         return resp
 
-    @backoff.on_exception(backoff.expo, Exception, max_tries=5)  # type: ignore
+    @backoff.on_exception(backoff.expo, Exception, max_tries=5)
     def acquire_access_token(self, timeout      = 10)        :
         if self.token_type == Type.AUTHORIZED_USER:
             resp = self._refresh_authorized_user(timeout=timeout)
