@@ -12,11 +12,11 @@ import os
 import pytest
 
 
-@pytest.fixture(scope='module')  # type: ignore
+@pytest.fixture(scope='module')
 def creds()       :
     return os.environ['GOOGLE_APPLICATION_CREDENTIALS']
 
 
-@pytest.fixture(scope='module')  # type: ignore
+@pytest.fixture(scope='module')
 def project()       :
     return 'dialpad-oss'
